@@ -1,5 +1,5 @@
 # Locale::Po4a::Pod -- Convert POD data to PO file, for translation.
-# $Id: Chooser.pm,v 1.35 2006/12/31 14:32:53 nekral-guest Exp $
+# $Id: Chooser.pm,v 1.38 2007-08-05 18:47:57 nekral-guest Exp $
 #
 # This program is free software; you may redistribute it and/or modify it
 # under the terms of GPL (see COPYING).
@@ -67,11 +67,11 @@ sub list {
 	."\n  - ".gettext("pod: Perl Online Documentation format.")
 	."\n  - ".gettext("sgml: either debiandoc or docbook DTD.")
 	."\n  - ".gettext("texinfo: The info page format.")
-#	."\n  - ".gettext("tex: generic TeX documents.")
+	."\n  - ".gettext("tex: generic TeX documents (see also latex).")
 	."\n  - ".gettext("text: simple text document.")
 #	."\n  - ".gettext("wml: WML documents.")
-#	."\n  - ".gettext("xhtml: XHTML documents.")
-#	."\n  - ".gettext("xml: generic XML documents.")
+	."\n  - ".gettext("xhtml: XHTML documents.")
+	."\n  - ".gettext("xml: generic XML documents (see also docbook).")
     );
     exit shift;
 }
@@ -112,7 +112,9 @@ L<Locale::Po4a::Po(3pm)>
 =item About modules:
 
 L<Locale::Po4a::Dia(3pm)>,
-L<Locale::Po4a::Html(3pm)>,
+L<Locale::Po4a::Docbook(3pm)>,
+L<Locale::Po4a::Guide(3pm)>,
+L<Locale::Po4a::Ini(3pm)>,
 L<Locale::Po4a::KernelHelp(3pm)>,
 L<Locale::Po4a::LaTeX(3pm)>,
 L<Locale::Po4a::Man(3pm)>,
@@ -120,6 +122,7 @@ L<Locale::Po4a::Pod(3pm)>,
 L<Locale::Po4a::Sgml(3pm)>,
 L<Locale::Po4a::Texinfo(3pm)>,
 L<Locale::Po4a::Text(3pm)>,
+L<Locale::Po4a::Xhtml(3pm)>,
 L<Locale::Po4a::Xml(3pm)>.
 
 =back
