@@ -1,5 +1,5 @@
 # Locale::Po4a::Po -- manipulation of po files 
-# $Id: Po.pm,v 1.76 2007/04/18 08:36:04 nekral-guest Exp $
+# $Id: Po.pm,v 1.78 2007-07-07 14:02:50 nekral-guest Exp $
 #
 # This program is free software; you may redistribute it and/or modify it
 # under the terms of GPL (see COPYING).
@@ -167,6 +167,7 @@ sub initialize {
     $self->{header_comment}=
 	escape_text( " SOME DESCRIPTIVE TITLE\n"
 		    ." Copyright (C) YEAR ".$self->{options}{'copyright-holder'}."\n"
+		    ." This file is distributed under the same license as the PACKAGE package.\n"
 		    ." FIRST AUTHOR <EMAIL\@ADDRESS>, YEAR.\n"
 		    ." \n"
 		    .", fuzzy");
@@ -487,14 +488,14 @@ sub gettextize {
 	# Make sure both type are the same
 	#
 	if ($typeorig ne $typetrans){
-	    $pores->write("/tmp/gettextization.failed.po");
+	    $pores->write("gettextization.failed.po");
 	    die wrap_msg(dgettext("po4a",
 	    	"po4a gettextization: Structure disparity between original and translated files:\n".
 		"msgid (at %s) is of type '%s' while\n".
 		"msgstr (at %s) is of type '%s'.\n".
 		"Original text: %s\n".
 		"Translated text: %s\n".
-	        "(result so far dumped to /tmp/gettextization.failed.po)")."%s",
+	        "(result so far dumped to gettextization.failed.po)")."%s",
 	        $reforig, $typeorig, $reftrans, $typetrans, $orig, $trans,$toobad);
 	}
 
