@@ -24,7 +24,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 #
 ########################################################################
 
@@ -329,6 +330,13 @@ sub set_tags_kind {
 
     foreach (qw(translate empty section verbatim ignore attributes qualify)) {
 	$self->{SGML}->{k}{$_} = $self->{options}{$_} ? $self->{options}{$_}.' ' : '';
+        # Remove the default behavior for the tags defined with the
+        # options.
+        foreach my $k (keys %kinds) {
+            foreach my $t (split(" ", $self->{SGML}->{k}{$_})) {
+                $kinds{$k} =~ s/\b$t\b//;
+            }
+        }
     }
 
     foreach (keys %kinds) {
@@ -711,7 +719,7 @@ sub parse_file {
 	    # Add the references of the added lines
 	    my $i;
 	    for ($i=0; $i<$len; $i++) {
-		$refs[$i+$pre] = "$main $entincl{$key}{'filename'}:".($i);
+		$refs[$i+$pre] = "$main $entincl{$key}{'filename'}:".($i+1);
 	    }
 
 	    if ($begin !~ m/\n[ \t]*$/s) {
@@ -742,6 +750,9 @@ sub parse_file {
         }
     }
     $origfile=~s/\G(.*?)&([A-Za-z_:][-_:.A-Za-z0-9]*|#[0-9]+|#x[0-9a-fA-F]+)\b/$1\{PO4A-amp\}$2/gs;
+    if (defined($xmlprolog) && length($xmlprolog)) {
+        $origfile=~s/\/>/\{PO4A-close\}>/gs;
+    }
 
     if ($debug{'refs'}) {
 	print "XX Resulting shifts\n";
@@ -849,10 +860,29 @@ sub parse_file {
     my $lastchar = ''; #
     my $buffer= ""; # what we will soon handle
 
+    # Keep a reference to the last line indicated by nsgmls
+    my $line=0;
+    # Unfortunately, nsgmls do not mention all the line changes.  We have
+    # to keep track of the number of lines seen in the "record ends".
+    my $adds=0;
+    # If the last line received contains only spaces, do not take it into
+    # account for the line reference of the paragraph.
+    my $empty_last_cdata=0;
     # run the appropriate handler for each event
     EVENT: while (my $event = $parse->next_event) {
-	# to build po entries
-	my $ref=$refs[$parse->line-1];
+	# get the line reference to build po entries
+	if ($line != $parse->line) {
+	    # nsgmls informs us of that the line changed. Reset $adds and
+	    # $empty_last_cdata
+	    $adds = 0;
+	    $empty_last_cdata = 0;
+	    $line = $parse->line;
+	}
+	my $ref=$refs[$parse->line-1 + $adds - $empty_last_cdata];
+	# In verbatim mode, keep the current line reference.
+	if ($verb) {
+	    $ref=$refs[$parse->line-1];
+	}
 	my $type;
 
 	if ($event->type eq 'start_element') {
@@ -891,14 +921,14 @@ sub parse_file {
                                     if ($translated =~ s/^$lattr=//) {
                                         $value=$translated;
                                     } else {
-                                        die wrap_mod("po4a::sgml", dgettext("po4a", "bad translation '%s' for '%s' in '%s'"), $translated, "$context$lattr", $ref);
+                                        die wrap_mod("po4a::sgml", dgettext("po4a", "bad translation '%s' for '%s' in '%s'"), $translated, $context.$lattr, $ref);
                                     }
                                 } else {
                                     $value = $self->translate($value, $ref, "attribute $context$lattr");
                                 }
                             }
                         }
-			if ($value =~ m/"/) { #"
+			if ($value =~ m/\"/) {
 			    $value = "'".$value."'";
 			} else {
 			    $value = '"'.$value.'"';
@@ -1043,6 +1073,7 @@ sub parse_file {
 
 	elsif ($event->type eq 'cdata') {
 	    my $cdata = $event->data;
+	    $empty_last_cdata=($cdata =~ m/^\s*$/);
 	    $cdata =~ s/{PO4A-lt}/</g;
 	    $cdata =~ s/{PO4A-gt}/>/g;
 	    $cdata =~ s/{PO4A-amp}/&/g;
@@ -1063,6 +1094,10 @@ sub parse_file {
 	    }
 	    $lastchar = substr($cdata, -1, 1);
 	    $buffer .= $cdata;
+	    if (defined($xmlprolog) && length($xmlprolog)) {
+		$buffer =~ s/>PO4A-close\}>/\/>/sg;
+		$buffer =~ s/PO4A-close\}>//sg; # This should not be necessary
+	    }
 	} # end of type eq 'cdata'
 
 	elsif ($event->type eq 'sdata') {
@@ -1074,6 +1109,8 @@ sub parse_file {
 	} # end of type eq 'sdata'
 
 	elsif ($event->type eq 're') {
+	    # End of record, the line reference shall be incremented.
+	    $adds +=1;
 	    if ($verb) {
 		# Check if this line of data appear on the same line
 		# than the previous tag. If not, append an end of line
@@ -1109,10 +1146,13 @@ sub parse_file {
     $self->pushline($buffer);
     close(IN);
     warn wrap_mod("po4a::sgml",
-                  dgettext("po4a","Warning: nsgmls is missing or non-".
-                  "functional.  Please make sure that nsgmls is present and ".
-                  "does not produce any error (with the -wno-valid option), ".
-                  "and report a bug otherwise.  Continuing...")) if ($? != 0);
+                  dgettext("po4a","Warning: nsgmls produced some errors.  ".
+                  "This is usually caused by po4a, which modifies the input ".
+                  "and restores it afterwards, causing the input of nsgmls ".
+                  "to be invalid.  This is usually safe, but you may wish ".
+                  "to verify the generated document with nsgmls -wno-valid.  ".
+                  "Continuing..."))
+        if ($? != 0 and $self->verbose() > 0);
     unlink ($tmpfile) unless ($debug{'refs'} or $debug{'nsgmls'});
 }
 
