@@ -16,7 +16,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with po4a; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 #
 ########################################################################
 
@@ -639,6 +640,8 @@ sub translate_buffer {
     my $t = ""; # a temporary string
 
     if ($buffer =~ /^\s*$/s) {
+        print STDERR "($buffer,@env)\n"
+            if ($debug{'translate_buffer'});
         return ($buffer, @env);
     }
     # verbatim blocks.
@@ -1090,14 +1093,14 @@ sub is_closed {
     # FIXME: { and } should not be counted in verbatim blocks
     # Remove comments
     $tmp =~ s/($RE_PRE_COMMENT)$RE_COMMENT.*//mg;
-    while ($tmp =~ /^.*?(?<!\\)(?:\\\\)*\{(.*)$/s) {
+    while ($tmp =~ /^.*?(?<!$RE_ESCAPE)(?:$RE_ESCAPE$RE_ESCAPE)*\{(.*)$/s) {
         $opening += 1;
         $tmp = $1;
     }
     $tmp = $paragraph;
     # Remove comments
     $tmp =~ s/($RE_PRE_COMMENT)$RE_COMMENT.*//mg;
-    while ($tmp =~ /^.*?(?<!\\)(?:\\\\)*\}(.*)$/s) {
+    while ($tmp =~ /^.*?(?<!$RE_ESCAPE)(?:$RE_ESCAPE$RE_ESCAPE)*\}(.*)$/s) {
         $closing += 1;
         $tmp = $1;
     }
