@@ -2,13 +2,13 @@
 
 # Po4a::Xhtml.pm 
 # 
-# extract and translate translatable strings from XHTML documents.
+# extract and translate translatable strings from Xhtml documents.
 # 
-# This code extracts plain text from tags and attributes from strict XHTML
+# This code extracts plain text from tags and attributes from strict Xhtml
 # documents.
 #
 # Copyright (c) 2005 by Yves Rütschlé <po4a@rutschle.net>
-# Copyright (c) 2007-2008 by Nicolas François <nicolas.francois@centraliens.net>
+# Copyright (c) 2007 by Nicolas François <nicolas.francois@centraliens.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,28 +26,30 @@
 #
 ########################################################################
 
-=encoding UTF-8
-
 =head1 NAME
 
-Locale::Po4a::Xhtml - convert XHTML documents from/to PO files
+Locale::Po4a::Xhtml - Convert Xhtml documents from/to PO files
 
 =head1 DESCRIPTION
 
-The po4a (PO for anything) project goal is to ease translations (and more
-interestingly, the maintenance of translations) using gettext tools on
-areas where they were not expected like documentation.
+The goal of the po4a (po for anything) project is to ease translations (and
+more interestingly, the maintenance of translations) using gettext tools on
+areas where they were not originally expected like documentation.
 
-Locale::Po4a::Xhtml is a module to help the translation of XHTML documents into
+Locale::Po4a::Xhtml is a module to help the translation of Xhtml documents into
 other [human] languages.
 
+Please note that this module is still experimental. It is not distributed in
+the official po4a releases since we don't feel it to be mature enough. If you
+insist on trying, check the CVS out.
+
 =head1 OPTIONS ACCEPTED BY THIS MODULE
 
 These are this module's particular options:
 
 =over 4
 
-=item B<includessi>[B<=>I<rootpath>]
+=item B<includessi>[=I<rootpath>]
 
 Include files specified by an include SSI (Server Side Includes) element
 (e.g. <!--#include virtual="/foo/bar.html" -->).
@@ -64,6 +66,8 @@ path to find files included by a B<virtual> attribute.
 This module is fully functional, as it relies in the L<Locale::Po4a::Xml>
 module. This only defines the translatable tags and attributes.
 
+It is derived from Jordi's DocBook module.
+
 "It works for me", which means I use it successfully on my personal Web site.
 However, YMMV: please let me know if something doesn't work for you. In
 particular, tables are getting no testing whatsoever, as we don't use them.
@@ -79,8 +83,7 @@ L<po4a(7)|po4a.7>, L<Locale::Po4a::TransTractor(3pm)>, L<Locale::Po4a::Xml(3pm)>
 
 =head1 COPYRIGHT AND LICENSE
 
- Copyright (c) 2004 by Yves Rütschlé <po4a@rutschle.net>
- Copyright (c) 2007-2008 by Nicolas François <nicolas.francois@centraliens.net>
+Copyright (c) 2004 by Yves Rütschlé <po4a@rutschle.net>
 
 This program is free software; you may redistribute it and/or modify it
 under the terms of GPL (see the COPYING file).
@@ -162,48 +165,38 @@ sub initialize {
         $self->{options}{'wrap'}=1;
         $self->{options}{'doctype'}=$self->{options}{'doctype'} || 'html';
 
-        # Default tags are translated (text rewrapped), and introduce a
-        # break.
-        # The following list indicates the list of tags which should be
-        # translated without rewrapping.
-        $self->{options}{'_default_translated'}.='
-                W<pre>
-        ';
-
-        # The following list indicates the list of tags which should be
-        # translated inside the current block, whithout introducing a
-        # break.
-        $self->{options}{'_default_inline'}.='
+        $self->{options}{'inline'}.='
                 <a> 
-                <abbr> 
-                <acronym> 
+                <object> 
+                <br> 
+                <span> 
+                <bdo> 
+                <map> 
+                <tt> 
+                <i> 
                 <b> 
                 <big> 
-                <bdo> 
-                <button> 
-                <cite> 
-                <code> 
-                <del>
-                <dfn> 
+                <small> 
                 <em> 
-                <i> 
-                <ins> 
-                <input> 
-                <kbd> 
-                <label> 
-                <object> 
+                <strong> 
+                <dfn> 
+                <code> 
                 <q> 
                 <samp> 
-                <select> 
-                <small> 
-                <span> 
-                <strong> 
+                <kbd> 
+                <var> 
+                <cite> 
+                <abbr> 
+                <acronym> 
                 <sub> 
                 <sup> 
+                <input> 
+                <select> 
                 <textarea> 
-                <tt> 
-                <u>
-                <var> 
+                <label> 
+                <button> 
+                <ins> 
+                <del>
         ';
 
         # Ignored tags: <img>
@@ -212,12 +205,10 @@ sub initialize {
         # write text (in which case you have bigger problems than this
         # program not inlining img: you now have to translate all your
         # images. That'll teach you).
-        # If you choose to translate images, you may also want to set
-        # <map> as placeholder and <area> as inline.
 
-        $self->{options}{'_default_attributes'}.='
-                alt
+        $self->{options}{'attributes'}.='
                 lang
+                alt
                 title
                 ';
         $self->treat_options;
