@@ -22,7 +22,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 #
 ########################################################################
 
@@ -51,16 +52,59 @@ use warnings;
 require Exporter;
 use vars qw(@ISA @EXPORT);
 @ISA = qw(Locale::Po4a::TransTractor);
-@EXPORT = qw(new initialize);
+@EXPORT = qw(new initialize @tag_types);
 
 use Locale::Po4a::TransTractor;
 use Locale::Po4a::Common;
+use Carp qw(croak);
 
 #It will mantain the path from the root tag to the current one
 my @path;
 
+#It will contain a list of external entities and their attached paths
+my %entities;
+
 my @comments;
 
+sub shiftline {
+    my $self = shift;
+    # call Transtractor's shiftline
+    my ($line,$ref) = $self->SUPER::shiftline();
+    return ($line,$ref) if (not defined $line);
+
+    for my $k (keys %entities) {
+        if ($line =~ m/^(.*?)&$k;(.*)$/s) {
+            my ($before, $after) = ($1, $2);
+            my $linenum=0;
+            my @textentries;
+
+            open (my $in, $entities{$k})
+                or croak wrap_mod("po4a::xml",
+                                  dgettext("po4a", "Can't read from %s: %s"),
+                                  $entities{$k}, $!);
+            while (defined (my $textline = <$in>)) {
+                $linenum++;
+                my $textref=$entities{$k}.":$linenum";
+                push @textentries, ($textline,$textref);
+            }
+            close $in
+                or croak wrap_mod("po4a::xml",
+                          dgettext("po4a", "Can't close %s after reading: %s"),
+                                  $entities{$k}, $!);
+
+            push @textentries, ($after, $ref);
+            $line = $before.(shift @textentries);
+            $ref .= " ".(shift @textentries);
+            while (@textentries) {
+                my ($r, $l) = (pop @textentries, pop @textentries);
+                $self->unshiftline($l,$r);
+            }
+        }
+    }
+
+    return ($line,$ref);
+}
+
 sub read {
 	my ($self,$filename)=@_;
 	push @{$self->{DOCPOD}{infile}}, $filename;
@@ -164,6 +208,39 @@ by custom tag options. See the "tags" option below.
 It makes the tags and attributes searching to work in a case insensitive
 way.  If it's defined, it will treat E<lt>BooKE<gt>laNG and E<lt>BOOKE<gt>Lang as E<lt>bookE<gt>lang.
 
+=item includeexternal
+
+When defined, external entities are included in the generated (translated)
+document, and for the extraction of strings.  If it's not defined, you
+will have to translate external entities separately as independent
+documents.
+
+=item ontagerror
+
+This option defines the behavior of the module when it encounter a invalid
+closing tag (a tag is closed, which does not match the last opening tag).
+It can take the following values:
+
+=over
+
+=item I<fail>
+
+This is the default value.
+The module will exit with an error.
+
+=item I<warn>
+
+The module will continue, and will issue a warning.
+
+=item I<silent>
+
+The module will continue without any warnings.
+
+=back
+
+Be careful when using this option.
+It is generally recommended to fix the input file.
+
 =item tagsonly
 
 Extracts only the specified tags in the "tags" option.  Otherwise, it
@@ -233,6 +310,8 @@ sub initialize {
 	$self->{options}{'placeholder'}='';
 	$self->{options}{'doctype'}='';
 	$self->{options}{'nodefault'}='';
+	$self->{options}{'includeexternal'}=0;
+	$self->{options}{'ontagerror'}="fail";
 
 	$self->{options}{'verbose'}='';
 	$self->{options}{'debug'}='';
@@ -400,7 +479,7 @@ single string.
 
 ##### Generic XML tag types #####' 
 
-my @tag_types = ( 
+our @tag_types = ( 
 	{	beginning	=> "!--#",
 		end		=> "--",
 		breaking	=> 0},
@@ -534,6 +613,10 @@ sub tag_trans_doctype {
 				$part1.= $1;
 				$part2 = $2;
 				$file = 1;
+				if ($self->{options}{'includeexternal'}) {
+					$entities{$name} = $part2;
+					$entities{$name} =~ s/^"?(.*?)".*$/$1/s;
+				}
 			}
 			if ((not $file) and (not $includenow)) {
 			    if ($part2 =~ m/^\s*(["'])(.*)\1(\s*>.*)$/s) {
@@ -574,7 +657,12 @@ sub tag_trans_close {
 
 	my $test = pop @path;
 	if (!defined($test) || $test ne $name ) {
-		die wrap_ref_mod($tag[1], "po4a::xml", dgettext("po4a", "Unexpected closing tag </%s> found. The main document may be wrong."), $name);
+		my $ontagerror = $self->{options}{'ontagerror'};
+		if ($ontagerror eq "warn") {
+			warn wrap_ref_mod($tag[1], "po4a::xml", dgettext("po4a", "Unexpected closing tag </%s> found. The main document may be wrong.  Continuing..."), $name);
+		} elsif ($ontagerror ne "silent") {
+			die wrap_ref_mod($tag[1], "po4a::xml", dgettext("po4a", "Unexpected closing tag </%s> found. The main document may be wrong."), $name);
+		}
 	}
 	return $self->join_lines(@tag);
 }
@@ -905,7 +993,7 @@ sub treat_attributes {
 								shift @tag;
 								shift @tag;
 							}
-							$tag[0] =~ /^(.*?)\Q$quot\E(.*)/;
+							$tag[0] =~ /^(.*?)\Q$quot\E(.*)/s;
 							$value .= $1;
 							$tag[0] = $2;
 						}
@@ -1013,7 +1101,12 @@ sub treat_content {
 					my $test = pop @path;
 					if (!defined($test) ||
 					    $test ne $tag[0] ) {
-						die wrap_ref_mod($tag[1], "po4a::xml", dgettext("po4a", "Unexpected closing tag </%s> found. The main document may be wrong."), $tag[0]);
+						my $ontagerror = $self->{options}{'ontagerror'};
+						if ($ontagerror eq "warn") {
+							warn wrap_ref_mod($tag[1], "po4a::xml", dgettext("po4a", "Unexpected closing tag </%s> found. The main document may be wrong.  Continuing..."), $tag[0]);
+						} elsif ($ontagerror ne "silent") {
+							die wrap_ref_mod($tag[1], "po4a::xml", dgettext("po4a", "Unexpected closing tag </%s> found. The main document may be wrong."), $tag[0]);
+						}
 					}
 
 					my $placeholder_regex = join("|", @{$self->{placeholder}});
